@@ -19,14 +19,12 @@
 
 // QT includes
 #include <qwidget.h>
-#include <qgroupbox.h>
 #include <qlist.h>
 
 // KDE includes
-#include <klocale.h>
-#include <kaccel.h>
 #include <krandomsequence.h>
 
+
 typedef enum _cardtype { // I don't use this anymore. But it helps to understand the numbers :)
 	        DECK=0,
 	        CA=1,SA=2,HA=3,DA=4,
@@ -53,7 +51,8 @@ class QLineEdit;
 class QFrame;
 
 // KDE classes
-class KAudio;
+class KAccel;
+class KConfig;
 
 // own classes
 class BetBox;
@@ -102,7 +101,7 @@ protected:
 	void newRound();
 	void noMoney();
 	void paintEvent( QPaintEvent * );	
-	void playSound(const char *filename);
+	void playSound(const QString &filename);
 	void setBetButtonEnabled(bool enabled);
 	void setHand(const QString& newHand, bool lastHand = true);
 	void setLastWinner(const QString& lastWinner);
@@ -125,7 +124,7 @@ protected:
 	Player* findHumanPlayer();
 
 	/**
-	  * This method first reads the config file then starts @ref setNewGameOptions() if it wasn't forbidden in config
+	  * This method first reads the config file then starts a newGame Dialog if it wasn't forbidden in config
 	  * 
 	  * After all options and defaults were set the method starts @ref initPoker() with only the number of the players as an argument or with a complete player class, depending on the options the player chose
 	  * @return True if successful false if player clicked 'cancel' in the new game dialog
@@ -172,26 +171,28 @@ public slots:
 	  *
 	  * The game can be loaded on startup by activating the button 'read from config'
 	 **/
-	void saveGame();
+	void saveGame(KConfig* conf);
+
+	bool loadGame(KConfig* conf);
+	bool loadGame();
 	void commandCallback(int id);
+	void newGame();
+	void saveGame();
 
 protected slots:
-	void newGame();
 	
 	void bTimerEvent();
 	void drawCardsEvent();
 	void drawClick();
-	void frameClick(CardWidget *);
 	void waveTimerEvent();
 
 	void betChange(int);
 	void adjustBet();
 	void out();
 
-	bool setNewGameOptions(bool hideReadingFromConfig = false);
-
 	void startWave();
 	void stopWave();
+	void toggleHeld(); // play a sound
 
 private:
 	int allPlayersNr; // used for constructing and deleting only
@@ -210,13 +211,14 @@ private:
 	int pot; 
 	int currentMustBet; // the minimum bet amount
 	int oldBet_raise;   // used for raising only
+	int drawDelay;
 
 	KRandomSequence random;
 
 	QPushButton 	*drawButton;    // the main Button
 	QLabel 		*wonLabel;      // the winner
 	QLabel 		*clickToHold; 
-	QLabel 		*weWillAdjustLabel; //TODO
+	QLabel 		*weWillAdjustLabel; 
 	bool		adjust;
 
 	QTimer       *blinkTimer; // the winning cards will blink 
@@ -237,9 +239,9 @@ private:
 
 	Status status;
 
-	int minBet;
-	int maxBet;
-	int cashPerRound;
+	int minBet; // the money the player will bet if he wants or not
+	int maxBet; // the money the player is allowed to bet - not that you must subtract minBet from this
+	int cashPerRound; // single player game: the money the player will pay every round
 };
 
 #endif
