@@ -28,7 +28,6 @@ this software.
 #include <kconfig.h>
 #include <kmenubar.h>
 #include <kstatusbar.h>
-#include <ktmainwindow.h>
 #include <qaccel.h>
 #include <qfile.h>
 #include <qpopupmenu.h>
@@ -46,7 +45,7 @@ const int default_width = 362;
 const int default_height = 460;
 
 GameWindow::GameWindow(QWidget *, const char *name)
-        : KTMainWindow(name)
+        : KMainWindow(0, name)
 {
 	setCaption(i18n("Smiletris"));
 
@@ -82,19 +81,18 @@ GameWindow::GameWindow(QWidget *, const char *name)
 	menu->insertItem(i18n("&Options"), options_popup);
 	menu->insertSeparator();
 	menu->insertItem(i18n("&Help"), help_popup);
-	setMenu(menu);
+
 	connect(menu, SIGNAL(moved(menuPosition)),
 		this, SLOT(movedMenu(menuPosition)));
 
 	status = new KStatusBar(this);
 	status->insertItem(i18n("Level: 99"), 1);
 	status->insertItem(i18n("Score: 999999"), 2);
-	setStatusBar(status);
 	status->changeItem("", 1);
 	status->changeItem("", 2);
 
 	game = new GameWidget(this);
-	setView(game);
+	setCentralWidget(game);
 	connect(game, SIGNAL(changedStats(int, int)),
 		this, SLOT(updateStats(int, int)));
 	connect(game, SIGNAL(gameOver()), this, SLOT(gameOver()));
@@ -250,7 +248,7 @@ void GameWindow::gameOver()
 			score.setNum(game->num_points);
 			config->writeEntry(s, score);
 			s = "Pos" + num + "Name";
-			config->writeEntry(s, d.name());
+			config->writeEntry(s, d.text());
 
 			ScoreDialog h(this);
 			h.exec();
@@ -270,3 +268,5 @@ void GameWindow::movedMenu(menuPosition pos)
 		resize(width(), height() - menu->height());
 	}
 }
+
+#include "gamewindow.moc"
