@@ -52,7 +52,7 @@ NewScoreDialog::NewScoreDialog(QWidget *parent, const char *name)
 	le->setFocus();
 }
 
-const char *NewScoreDialog::name()
+QString NewScoreDialog::text()
 {
 	return le->text();
 }
