@@ -8,7 +8,7 @@
 #include <qlist.h>
 #include <qfileinfo.h>
 
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
 
 #include "rattler.h"
 #include "trys.h"
@@ -16,7 +16,11 @@
 #include "progress.h"
 #include "levels.h"
 
-class Game : public KTMainWindow
+class KAction;
+class KSelectAction;
+class KRadioAction;
+
+class Game : public KMainWindow
   {
     Q_OBJECT
 public:
@@ -25,10 +29,10 @@ public:
 protected:
     //   void keyPressEvent( QKeyEvent * );
 private slots:
-    void ballsChecked(int);
-    void skillChecked(int);
-    void snakesChecked(int);
-    void pixChecked(int);
+    void ballsChecked();
+    void skillChecked();
+    void snakesChecked();
+    void pixChecked();
 
     void newGame();
     void pauseGame();
@@ -57,21 +61,11 @@ private:
     void checkMenuItems();
     void lookupBackgroundPixmaps();
 
-    KMenuBar *menubar;
-    QPopupMenu *game;
-    QPopupMenu *options;
-    QPopupMenu *balls;
-    QPopupMenu *snakes;
-    QPopupMenu *pix;
-
-    int pauseID;
-
-    int ballsID[4];
-    int snakesID[4];
-    int skillID[4];
-
-    QArray<int> pixID;
-
+    KAction *pause;
+    KSelectAction *balls;
+    KSelectAction *snakes;
+    KRadioAction *skills[4];
+    KSelectAction *pix;
 
     QStringList backgroundPixmaps;
 };
