@@ -5,7 +5,6 @@
 #include <qcolor.h>
 #include <qlabel.h>
 #include <qkeycode.h>
-#include <qmessagebox.h>
 #include <qbitarray.h>
 
 #include <kapp.h>
@@ -20,6 +19,7 @@
 #include "pixServer.h"
 #include <klocale.h>
 #include <kconfig.h>
+#include <kmessagebox.h>
 
 
 QBitArray gameState(5);
@@ -32,6 +32,7 @@ Rattler::Rattler( QWidget *parent, const char *name )
     setFocusPolicy(QWidget::StrongFocus);
 
     KConfig *conf = kapp->config();
+    conf->setGroup("General");
     numBalls = conf->readNumEntry("Balls", 1);
     numSnakes = conf->readNumEntry("ComputerSnakes", 1);
     skill = conf->readNumEntry("Skill", 1);
@@ -80,7 +81,7 @@ void Rattler::paintEvent( QPaintEvent *e)
     bitBlt(this, rect.x(), rect.y(),
               &levelPix, rect.x(), rect.y(), rect.width(), rect.height());
     //most Below here was moved to timerEvent where it belongs...
-  
+
 
 
 }
@@ -129,6 +130,7 @@ void Rattler::timerEvent( QTimerEvent * )
 void Rattler::initKeys()
 {
     KConfig *conf = kapp->config();
+    conf->setGroup("General");
 
     QString up("Up");
     up = conf->readEntry("upKey", up);
@@ -348,16 +350,14 @@ void Rattler::restart()
 
     if (gameState.testBit(Paused) || gameState.testBit(Playing)) {
 
-	switch( QMessageBox::information( this, i18n("Snake Race"),
-					  i18n("A game is already started\n"
-					  "Start a new one ?\n"),
-					  i18n("&Yes"), i18n("&No"),
-					  QString::null, 1 ) ) {
-	case 0:
+	switch( KMessageBox::questionYesNo( this,
+					    i18n("A game is already started.\n"
+						 "Start a new one?\n"),  i18n("Snake Race"))) {
+	case KMessageBox::No:
 	    if ( gameState.testBit(Paused))
 		emit togglePaused();
 	    break;
-	case 1:
+	case KMessageBox::Yes:
 	    if ( !gameState.testBit(Paused))
 		start();
 	    return;
@@ -613,3 +613,5 @@ void Rattler::reloadRoomPixmap()
     pix->initRoomPixmap();
     demo();
 }
+
+#include "rattler.moc"
