@@ -5,7 +5,6 @@
  ------------------------------------------------------------- */
 
 #include <kapp.h>
-#include <ktmainwindow.h>
 #include <kimageio.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
@@ -16,7 +15,7 @@
 
 static const char *description = I18N_NOOP("Potato game for kids");
 
-static const char *version = "v0.0.1";
+static const char *version = "v0.1";
 
 
 int main(int argc, char *argv[])
