@@ -1,4 +1,4 @@
-/***************************************************************************
+/*
                           lskat.cpp  -  description
                              -------------------
     begin                : Tue May  2 15:47:11 CEST 2000
@@ -41,15 +41,16 @@
 #include "aboutdlg.h"
 #include "msgdlg.h"
 
+#include <stdlib.h>
 
-LSkatApp::LSkatApp()
+LSkatApp::LSkatApp() : KMainWindow(0)
 {
   config=kapp->config();
 
    // localise data file
-   QString file=QCString("lskat/grafix/1.png");
-   mGrafix=kapp->dirs()->findResourceDir(QCString("data"),file); 
-   if (mGrafix.isNull()) mGrafix=QCString("grafix/");
+   QString file=QString::fromLatin1("lskat/grafix/1.png");
+   mGrafix=kapp->dirs()->findResourceDir("data", file); 
+   if (mGrafix.isNull()) mGrafix = QCString("grafix/");
    else mGrafix+=QCString("lskat/grafix/");
    if (global_debug>3) printf("Localised datafile=%s\n",mGrafix.latin1());
 
@@ -133,21 +134,21 @@ void LSkatApp::initMenuBar()
   // MENUBAR
   fileMenu = new QPopupMenu();
 //  fileMenu->insertSeparator();
-  fileMenu->insertItem(BarIcon(QCString("filenew")), i18n("&New game"), ID_FILE_NEW);
-  fileMenu->insertItem(BarIcon(QCString("stop")),i18n("&End game"), ID_FILE_CLOSE);
+  fileMenu->insertItem(SmallIcon("filenew"), i18n("&New game"), ID_FILE_NEW);
+  fileMenu->insertItem(SmallIcon("stop"),i18n("&End game"), ID_FILE_CLOSE);
   fileMenu->insertSeparator();
-  fileMenu->insertItem(BarIcon(QCString("flag")),i18n("&Clear statistics..."), ID_FILE_STATISTICS);
-  fileMenu->insertItem(BarIcon(QCString("openterm")),i18n("Send &Message..."), ID_FILE_MESSAGE);
+  fileMenu->insertItem(SmallIcon("flag"),i18n("&Clear statistics..."), ID_FILE_STATISTICS);
+  fileMenu->insertItem(SmallIcon("openterm"),i18n("Send &Message..."), ID_FILE_MESSAGE);
   fileMenu->insertSeparator();
   fileMenu->insertSeparator();
-  fileMenu->insertItem(BarIcon(QCString("exit")),i18n("E&xit"), ID_FILE_QUIT);
+  fileMenu->insertItem(SmallIcon("exit"),i18n("E&xit"), ID_FILE_QUIT);
 
 	
   ///////////////////////////////////////////////////////////////////
   // menuBar entry editMenu
   editMenu = new QPopupMenu();
-  editMenu->insertItem(BarIcon(QCString("undo")), i18n("&Undo move"), ID_EDIT_UNDO);
-  editMenu->insertItem(BarIcon(QCString("redo")), i18n("&Redo move"), ID_EDIT_REDO);
+  editMenu->insertItem(SmallIcon("undo"), i18n("&Undo move"), ID_EDIT_UNDO);
+  editMenu->insertItem(SmallIcon("redo"), i18n("&Redo move"), ID_EDIT_REDO);
 
   ///////////////////////////////////////////////////////////////////
   // menuBar entry viewMenu
@@ -206,11 +207,6 @@ void LSkatApp::initMenuBar()
 
       for (int i=0;i<NO_OF_DECKS;i++)
         popDeck->insertItem(i18n("Deck &%1").arg(i+1),ID_DECK_1+i);
-      /*
-      popDeck->insertItem(i18n("Deck &2"),ID_DECK_2);
-      popDeck->insertItem(i18n("Deck &3"),ID_DECK_3);
-      popDeck->insertItem(i18n("Deck &4"),ID_DECK_4);
-      */
 
       optionsMenu->insertItem(i18n("&Startplayer"),popStartplayer);
       optionsMenu->insertItem(i18n("Player &1 played by"),popPlayer1);
@@ -288,16 +284,16 @@ void LSkatApp::initToolBar()
 
   ///////////////////////////////////////////////////////////////////
   // TOOLBAR
-  toolBar()->insertButton(BarIcon(QCString("filenew")), ID_FILE_NEW, true, i18n("New File"));
-  toolBar()->insertButton(BarIcon(QCString("fileopen")), ID_FILE_OPEN, true, i18n("Open File"));
-  toolBar()->insertButton(BarIcon(QCString("filefloppy")), ID_FILE_SAVE, true, i18n("Save File"));
-  toolBar()->insertButton(BarIcon(QCString("fileprint")), ID_FILE_PRINT, true, i18n("Print"));
+  toolBar()->insertButton(BarIcon("filenew"), ID_FILE_NEW, true, i18n("New File"));
+  toolBar()->insertButton(BarIcon("fileopen"), ID_FILE_OPEN, true, i18n("Open File"));
+  toolBar()->insertButton(BarIcon("filesave"), ID_FILE_SAVE, true, i18n("Save File"));
+  toolBar()->insertButton(BarIcon("fileprint"), ID_FILE_PRINT, true, i18n("Print"));
   toolBar()->insertSeparator();
-  toolBar()->insertButton(BarIcon(QCString("editcut")), ID_EDIT_CUT, true, i18n("Cut"));
-  toolBar()->insertButton(BarIcon(QCString("editcopy")), ID_EDIT_COPY, true, i18n("Copy"));
-  toolBar()->insertButton(BarIcon(QCString("editpaste")), ID_EDIT_PASTE, true, i18n("Paste"));
+  toolBar()->insertButton(BarIcon("editcut"), ID_EDIT_CUT, true, i18n("Cut"));
+  toolBar()->insertButton(BarIcon("editcopy"), ID_EDIT_COPY, true, i18n("Copy"));
+  toolBar()->insertButton(BarIcon("editpaste"), ID_EDIT_PASTE, true, i18n("Paste"));
   toolBar()->insertSeparator();
-  toolBar()->insertButton(BarIcon(QCString("help")), ID_HELP_CONTENTS, SIGNAL(clicked()),
+  toolBar()->insertButton(BarIcon("help"), ID_HELP_CONTENTS, SIGNAL(clicked()),
   				this, SLOT(appHelpActivated()), true,i18n("Help"));
 
   ///////////////////////////////////////////////////////////////////
@@ -325,7 +321,7 @@ void LSkatApp::initStatusBar()
 
   slotStatusTime();
   slotStatusMover(i18n("(c) Martin Heni   "));
-  slotStatusMsg(i18n("Welcome to ")+TITLE);
+  slotStatusMsg(i18n("Welcome to Lieutnant Skat"));
 
   // status bar clock
   statusTimer=new QTimer(this);
@@ -346,13 +342,13 @@ void LSkatApp::initDocument()
 void LSkatApp::initView()
 { 
   ////////////////////////////////////////////////////////////////////
-  // create the main widget here that is managed by KTMainWindow's view-region and
+  // create the main widget here that is managed by KMainWindow's view-region and
   // connect the widget to your document to display document contents.
 
   view = new LSkatView(this);
   doc->addView(view);
-  setView(view);	
-  setCaption(TITLE);
+  setCentralWidget(view);	
+  setCaption(i18n("Lieutnant Skat"));
 
 }
 
@@ -384,14 +380,14 @@ LSkatDoc *LSkatApp::getDocument() const
 
 void LSkatApp::saveOptions()
 {	
-  config->setGroup(QCString("General Options"));
-  config->writeEntry(QCString("Geometry"), size());
+  config->setGroup("General Options");
+  config->writeEntry("Geometry", size());
 #ifdef USE_TOOLBAR
-  config->writeEntry(QCString("Show Toolbar"), toolBar()->isVisible());
-  config->writeEntry(QCString("ToolBarPos"), (int) toolBar()->barPos());
-  config->writeEntry(QCString("Recent Files"), recentFiles);
+  config->writeEntry("Show Toolbar", toolBar()->isVisible());
+  config->writeEntry("ToolBarPos", (int) toolBar()->barPos());
+  config->writeEntry("Recent Files", recentFiles);
 #endif
-  config->writeEntry(QCString("Show Statusbar"),statusBar()->isVisible());
+  config->writeEntry("Show Statusbar",statusBar()->isVisible());
   doc->WriteConfig(config);
 }
 
@@ -399,32 +395,28 @@ void LSkatApp::saveOptions()
 void LSkatApp::readOptions()
 {
 	
-  config->setGroup(QCString("General Options"));
+  config->setGroup("General Options");
 
 #ifdef USE_TOOLBAR
   // bar status settings
-  bool bViewToolbar = config->readBoolEntry(QCString("Show Toolbar"), true);
+  bool bViewToolbar = config->readBoolEntry("Show Toolbar", true);
   viewMenu->setItemChecked(ID_VIEW_TOOLBAR, bViewToolbar);
   if(!bViewToolbar)
-  {
-     enableToolBar(KToolBar::Hide);
-  }
+    toolBar()->hide();
 #endif	
-  bool bViewStatusbar = config->readBoolEntry(QCString("Show Statusbar"), true);
+  bool bViewStatusbar = config->readBoolEntry("Show Statusbar", true);
   viewMenu->setItemChecked(ID_VIEW_STATUSBAR, bViewStatusbar);
   if(!bViewStatusbar)
-  {
-    enableStatusBar(KStatusBar::Hide);
-  }
+    statusBar()->hide();
 
 #ifdef USE_TOOLBAR
   // bar position settings
   KToolBar::BarPosition toolBarPos;
-  toolBarPos=(KToolBar::BarPosition) config->readNumEntry(QCString("ToolBarPos"), KToolBar::Top);
+  toolBarPos=(KToolBar::BarPosition) config->readNumEntry("ToolBarPos", KToolBar::Top);
   toolBar()->setBarPos(toolBarPos);
 #endif	
 
-  QSize size=config->readSizeEntry(QCString("Geometry"));
+  QSize size=config->readSizeEntry("Geometry");
   if(!size.isEmpty())
   {
     resize(size);
@@ -442,8 +434,8 @@ void LSkatApp::saveProperties(KConfig *_cfg)
   else
   {
     QString filename=doc->getAbsFilePath();	
-    _cfg->writeEntry(QCString("filename"), filename);
-    _cfg->writeEntry(QCString("modified"), doc->isModified());
+    _cfg->writeEntry("filename", filename);
+    _cfg->writeEntry("modified", doc->isModified());
 		
     QString tempname = kapp->tempSaveName(filename);
     doc->saveDocument(tempname);
@@ -453,8 +445,8 @@ void LSkatApp::saveProperties(KConfig *_cfg)
 
 void LSkatApp::readProperties(KConfig* _cfg)
 {
-  QString filename = _cfg->readEntry(QCString("filename"), QCString(""));
-  bool modified = _cfg->readBoolEntry(QCString("modified"), false);
+  QString filename = _cfg->readEntry("filename", QCString(""));
+  bool modified = _cfg->readBoolEntry("modified", false);
   if(modified)
   {
     bool canRecover;
@@ -478,8 +470,8 @@ void LSkatApp::readProperties(KConfig* _cfg)
     }
   }
 
-  QString caption=kapp->caption();	
-  setCaption(TITLE);
+  //QString caption=kapp->caption();	
+  setCaption(i18n("Lieutnant Skat"));
 }		
 
 bool LSkatApp::queryClose()
@@ -523,7 +515,7 @@ void LSkatApp::slotFileStatistics()
    message=i18n("Do you really want to clear the all time\n"
                 "statistical data?\n");
 
-  if (KMessageBox::Yes==KMessageBox::questionYesNo(this,message,TITLE))
+  if (KMessageBox::Yes==KMessageBox::questionYesNo(this,message))
   {
     doc->ClearStats();
     doc->slotUpdateAllViews(0);
@@ -599,7 +591,7 @@ void LSkatApp::slotFileQuit()
   saveOptions();
   // close the first window, the list makes the next one the first again.
   // This ensures that queryClose() is called on each window to ask for closing
-  KTMainWindow* w;
+  KMainWindow* w;
   if(memberList)
   {
     for(w=memberList->first(); w!=0; w=memberList->first())
@@ -623,12 +615,12 @@ void LSkatApp::slotViewToolBar()
   if( viewMenu->isItemChecked(ID_VIEW_TOOLBAR))
   {
     viewMenu->setItemChecked(ID_VIEW_TOOLBAR, false);
-    enableToolBar(KToolBar::Hide);
+    toolBar()->hide();
   }
   else
   {
     viewMenu->setItemChecked(ID_VIEW_TOOLBAR, true);
-    enableToolBar(KToolBar::Show);
+    toolBar()->show();
   }		
 
   slotStatusMsg(i18n(IDS_STATUS_DEFAULT));
@@ -706,12 +698,12 @@ void LSkatApp::slotViewStatusBar()
   if( viewMenu->isItemChecked(ID_VIEW_STATUSBAR))
   {
     viewMenu->setItemChecked(ID_VIEW_STATUSBAR, false);
-    enableStatusBar(KStatusBar::Hide);
+    statusBar()->hide();
   }
   else
   {
     viewMenu->setItemChecked(ID_VIEW_STATUSBAR, true);
-    enableStatusBar(KStatusBar::Show);
+    statusBar()->show();
   }
 
   slotStatusMsg(i18n(IDS_STATUS_DEFAULT));
@@ -865,7 +857,7 @@ void LSkatApp::statusCallback(int id_)
   switch (id_)
   {
     case ID_FILE_NEW:
-         slotStatusHelpMsg(i18n("Creates a new document"));
+         slotStatusHelpMsg(i18n("Starts a new game"));
          break;
 
     case ID_FILE_STATISTICS:
@@ -877,7 +869,7 @@ void LSkatApp::statusCallback(int id_)
          break;
 
     case ID_FILE_CLOSE:
-         slotStatusHelpMsg(i18n("Closes the actual document"));
+         slotStatusHelpMsg(i18n("Ends the current game"));
          break;
 
     case ID_FILE_QUIT:
@@ -913,8 +905,8 @@ void LSkatApp::statusCallback(int id_)
     case ID_LEVEL_9:
     case ID_LEVEL_10:
          s.setNum((int)(id_-ID_LEVEL_1+1));
-         s=i18n("Set the level of the computer player to ")+s;
-         slotStatusHelpMsg(i18n(s));
+         s=i18n("Set the level of the computer player to %1").arg(s);
+         slotStatusHelpMsg(s);
          break;
 
     case ID_DECK_1:
@@ -927,8 +919,8 @@ void LSkatApp::statusCallback(int id_)
     case ID_DECK_8:
     case ID_DECK_9:
          s.setNum((int)(id_-ID_DECK_1+1));
-         s=i18n("Set the carddeck to ")+s;
-         slotStatusHelpMsg(i18n(s));
+         s=i18n("Set the carddeck to %1").arg(s);
+         slotStatusHelpMsg(s);
          break;
 
     case ID_STARTPLAYER_1:
@@ -988,7 +980,7 @@ void LSkatApp::slotStatusNames(){
   if (!doc->IsRunning()) msg=i18n("No game running");
   else
   {
-    msg=doc->GetName(doc->GetCurrentPlayer())+i18n(" to move ...");
+    msg=i18n("%1 to move ...").arg(doc->GetName(doc->GetCurrentPlayer()));
   }
   slotStatusMover(msg);
 }
@@ -1176,7 +1168,7 @@ void LSkatApp::NewGame()
     KMessageBox::error(this,
       i18n("Cannot start player 1. Maybe the network conenction\n"
            "failed or the computer player process file is not\n"
-           "found.\n"),TITLE);
+           "found.\n"));
     return ;
   }
   res=MakeInputDevice(1);
@@ -1185,7 +1177,7 @@ void LSkatApp::NewGame()
     KMessageBox::error(this,
       i18n("Cannot start player 2. Maybe the network conenction\n"
            "failed or the computer player process file is not\n"
-           "found.\n"),TITLE);
+           "found.\n"));
     return ;
   }
   // Remote game is started when receiving the start mesage .. not here!
@@ -1240,22 +1232,19 @@ bool LSkatApp::MakeInputDevice(int no)
         if (!res)
         {
           QProgressDialog *progress;
-          QString s,p;
+          QString s;
           int tim,j;
           tim=10000;
-          p.setNum(port);
-          if (host&&host.length()>0)
+          if (!host.isEmpty())
           {
-            s=i18n("Remote connection to ")+host
-              +QString(QCString(":"))+p+QString(QCString("...   "));
+            s=i18n("Remote connection to %1:%2...").arg(host).arg(port);
           }
           else
           {
-            s=QString(i18n("Offering remote connection on port "))+
-              p+QString(QCString("...   "));
+            s=i18n("Offering remote connection on port %1 ...").arg(port);
           }
           progress=new QProgressDialog(s, i18n("Abort"), tim, this,0,true );
-          progress->setCaption(TITLE);
+          progress->setCaption(i18n("Lieutnant Skat"));
           for (j=0; j<tim; j++)
           {
             progress->setProgress( j );
@@ -1405,16 +1394,16 @@ void LSkatApp::slotReceiveInput(KEMessage *msg,int id)
     {
       if (move==0)
       {
-        message=QString(i18n("Remote connection lost for player 1..."));
-        KMessageBox::information(this,message,TITLE);
-        slotStatusMsg(i18n(message));
+        message=i18n("Remote connection lost for player 1...");
+        KMessageBox::information(this,message);
+        slotStatusMsg(message);
         slotPlayer1(KG_INPUTTYPE_INTERACTIVE);
       }
       else
       {
-        message=QString(i18n("Remote connection lost for player 2..."));
-        KMessageBox::information(this,message,TITLE);
-        slotStatusMsg(i18n(message));
+        message=i18n("Remote connection lost for player 2...");
+        KMessageBox::information(this,message);
+        slotStatusMsg(message);
         slotPlayer2(KG_INPUTTYPE_INTERACTIVE);
       }
     }
@@ -1425,7 +1414,7 @@ void LSkatApp::slotReceiveInput(KEMessage *msg,int id)
     if (msg->GetData(QCString("Message"),p,size))
     {
       message=i18n("Message from remote player:\n")+p;
-      KMessageBox::information(this,message,TITLE);
+      KMessageBox::information(this,message);
       if (global_debug>3)
         printf("MESSAGE **** %s ****\n",message.latin1());
     }
@@ -1443,7 +1432,7 @@ void LSkatApp::slotReceiveInput(KEMessage *msg,int id)
 
     msg->GetData(QCString("EndGame"),move);
     message=i18n("Remote player ended game...");
-    KMessageBox::information(this,message,TITLE);
+    KMessageBox::information(this,message);
     slotStatusMsg(message);
 
     doc->EndGame(true);	
@@ -1537,7 +1526,7 @@ void LSkatApp::Move(int x,int y,int player,bool remote)
   {
      KMessageBox::error(this, 
        i18n("Severe internal error. Move to illegal position.\n"
-            "Restart game and report but to the developper.\n"),TITLE);
+            "Restart game and report bug to the developer.\n"));
     return ;
   }
   int res=doc->PrepareMove(player,y*4+x);
@@ -1563,17 +1552,17 @@ void LSkatApp::Move(int x,int y,int player,bool remote)
   {
      KMessageBox::information(this, 
        i18n("Ehm, this move would not follow the rulebook.\n"
-            "Better think again!\n"),TITLE);
+            "Better think again!\n"));
     return ;
   }
   else if (res==-2)
   {
-     KMessageBox::information(this,i18n("It is not your turn.\n"),TITLE);
+     KMessageBox::information(this,i18n("It is not your turn.\n"));
     return ;
   }
   else
   {
-     KMessageBox::information(this, i18n("This move is not possible.\n"),TITLE);
+     KMessageBox::information(this, i18n("This move is not possible.\n"));
     return ;
   }
 }
@@ -1652,7 +1641,4 @@ void LSkatApp::SetGrafix(QString s)
   mGrafix=s;
 }
 
-
-
-
-
+#include "lskat.moc"
